==> phpaga-0.3.tar.bz2: phpaga-0.3/lib/auth.php <==
<?php
/**
 * phpaga
 *
 * User authentication functionality.
 *
 * This file contains the necessary routines to authenticate users.
 *
 * @author Florian Lanthaler <florian@phpaga.net>
 * @version $Id: auth.php 656 2006-01-19 20:48:39Z worf $
 *
 * Copyright (c) 2002, Florian Lanthaler <florian@phpaga.net>
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *    * Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *
 *    * Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in
 *      the documentation and/or other materials provided with the
 *      distribution.
 *
 *    * Neither the name of Florian Lanthaler nor the names of his
 *      contributors may be used to endorse or promote products derived
 *      from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/**
 * Authenticates a user. Gets login and password and verifies them
 * against the entries in the user database.
 *
 * @param string $login   User name
 * @param string $passwd  Users's password
 * @param int    $userID  Users's ID
 *
 * @return int   $result  A result code.
 *
 * @author Florian Lanthaler <florian@phpaga.net>
 * @since phpaga 0.1
 */

function phpaga_auth_login ($login, $passwd, &$userID)
{

    $db = "";
    $result = "";

    if (!strlen($login))
        return PHPAGA_ERR_USER_INVALIDID;

    phpaga_db_connect($db);

    $query = "SELECT usr_id FROM users ".
        "WHERE usr_login = ".$db->quoteSmart($login).
        " AND usr_passwd = ".$db->quoteSmart(phpaga_password($passwd));

    $result = $db->query($query);

    if (DB::isError($result))
        return PHPAGA_ERR_DB_EXEC_QUERY;

    if ($result->numRows() < 1)
    {
        phpaga_log(sprintf("LOGIN FAILURE: %s", $login));
        return PHPAGA_ERR_DB_NO_ROWS;
    }

    $qrow = $result->fetchRow();
    $result->free();

    if (is_array($qrow))
    {
        $userID = $qrow["usr_id"];
        phpaga_log(sprintf("LOGIN: %s", $login));
        return USER_AUTHENTICATED;
    }
    else
    {
        phpaga_log(sprintf("LOGIN FAILURE: %s", $login));
        return PHPAGA_ERR_USER_INVALIDID;
    }
}

?>

==> phpaga-0.6.tar.bz2: phpaga-0.6/lib/auth.php <==
<?php
/**
 * phpaga
 *
 * User authentication functionality.
 *
 * This file contains the necessary routines to authenticate users.
 *
 * @author Florian Lanthaler <florian@phpaga.net>
 * @version $Id$
 *
 * Copyright (c) 2002, Florian Lanthaler <florian@phpaga.net>
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *    * Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *
 *    * Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in
 *      the documentation and/or other materials provided with the
 *      distribution.
 *
 *    * Neither the name of Florian Lanthaler nor the names of his
 *      contributors may be used to endorse or promote products derived
 *      from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/**
 * Authenticates a user. Gets login and password and verifies them
 * against the entries in the user database.
 *
 * @param string $login   User name
 * @param string $passwd  Users's password
 * @param int
 *
 * @return int   $userID  Users's ID. A PhPagaError object on failure.
 *
 * @author Florian Lanthaler <florian@phpaga.net>
 * @since phpaga 0.1
 */

function phpaga_auth_login($login, $passwd)
{

    $userID = null;

    if (!strlen($login))
        return PhPagaError::raiseErrorByCode(PHPAGA_ERR_USER_INVALIDID);

    $d = new PhPagaDbData;

    $userID = $d->queryOneVal('SELECT usr_id FROM users WHERE usr_login = ? AND usr_passwd = ?',
                              array($login, phpaga_password($passwd)));

    if (PhPagaError::isError($userID))
        return $userID;

    if (!strlen($userID) && !is_numeric($userID)) {
        phpaga_log(sprintf("LOGIN FAILURE: %s", $login));
        return PhPagaError::raiseErrorByCode(PHPAGA_ERR_USER_INVALIDID);
    }

    phpaga_log(sprintf("LOGIN: %s", $login));
    return $userID;
}

?>
